@@ -13,11 +13,6 @@ Usage (module):
     import jc
     result = jc.parse('du', du_command_output)
 
-    or
-
-    import jc.parsers.du
-    result = jc.parsers.du.parse(du_command_output)
-
 Schema:
 
     [
